@@ -1,5 +1,6 @@
 pub use tree_parser::*;
+pub use gxi_parser::*;
 
-pub mod comp_parser;
+mod gxi_parser;
 mod init_type;
 mod tree_parser;
